@@ -16,9 +16,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: gestures.c,v 1.1 2003/11/12 20:04:01 chpe Exp $
+ *  $Id: gestures.c,v 1.1.6.1 2004/09/26 16:22:39 chpe Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "ephy-gestures-extension.h"
 #include "ephy-gesture.h"
 #include "ephy-debug.h"
@@ -26,6 +30,8 @@
 #include <glib-object.h>
 #include <gmodule.h>
 
+G_MODULE_EXPORT GType register_module (GTypeModule *module);
+
 G_MODULE_EXPORT GType
 register_module (GTypeModule *module)
 {
