@@ -22,7 +22,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: page-info-dialog.c,v 1.20 2004/09/13 09:48:28 chpe Exp $
+ *  $Id: page-info-dialog.c,v 1.20.2.3 2004/10/08 16:58:32 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -51,6 +51,7 @@
 #include <gtk/gtkuimanager.h>
 #include <gtk/gtkstock.h>
 #include <gtk/gtkclipboard.h>
+#include <gtk/gtkmain.h>
 
 #include <libgnomevfs/gnome-vfs-uri.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
@@ -58,10 +59,11 @@
 
 #include "mozilla/mozilla-helpers.h"
 
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <glib/gconvert.h>
 
 #include <time.h>
+#include <string.h>
 
 /* Glade callbacks */
 void page_info_dialog_close_button_clicked_cb	  (GtkWidget *button,
@@ -597,7 +599,6 @@ general_info_page_fill (InfoPage *page)
 	EphyEmbed *embed = dialog->priv->embed;
 	EmbedPageProperties *props;
 	/* GtkTreeView *page_info_meta_list; */
-	GList *i;
 	const char *text;
 	const char *date_hack = "%c"; /* quiet gcc */
 	char date[128];
@@ -912,7 +913,6 @@ page_info_image_box_realize_cb (GtkContainer *box,
 	TreeviewInfoPage *tpage = (TreeviewInfoPage *) dialog->priv->pages[IMAGES_PAGE];
 	ImagesInfoPage *page = (ImagesInfoPage *) tpage;
 	EphyEmbed *embed;
-	GtkWidget *treeview;
 
 	page->embed = embed = EPHY_EMBED (ephy_embed_factory_new_object ("EphyEmbed"));
 
@@ -935,10 +935,7 @@ static void
 images_treeview_selection_changed_cb (GtkTreeSelection *selection,
 				      ImagesInfoPage *page)
 {
-	GtkTreeModel *model;
-	GtkTreeIter iter;
 	char *url;
-	gboolean has_selected;
 
 	url = images_get_selected_image_url (page);
 
@@ -1078,7 +1075,6 @@ static void
 images_info_page_fill (InfoPage *ipage)
 {
 	TreeviewInfoPage *tpage = (TreeviewInfoPage *) ipage;
-	ImagesInfoPage *page = (ImagesInfoPage *) ipage;
 	PageInfoDialog *dialog = ipage->dialog;
 	GtkListStore *store = tpage->store;
 	GtkTreeIter iter;
@@ -1138,15 +1134,55 @@ enum
 	COL_LINK_REL
 };
 
+static char *
+links_get_selected_link_url (LinksInfoPage *page)
+{
+	TreeviewInfoPage *tpage = (TreeviewInfoPage *) page;
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+	char *address = NULL;
+
+	if (gtk_tree_selection_get_selected (tpage->selection, &model, &iter))
+	{
+		gtk_tree_model_get (model, &iter,
+				    COL_LINK_URL, &address,
+				    -1);
+	}
+
+	return address;
+}
+
+static void
+links_copy_link_address_cb (GtkAction *action,
+			    LinksInfoPage *page)
+{
+	char *address;
+
+	address = links_get_selected_link_url (page);
+	if (address == NULL) return;
+
+	gtk_clipboard_set_text (gtk_clipboard_get (GDK_NONE),
+				address, -1);
+	gtk_clipboard_set_text (gtk_clipboard_get (GDK_SELECTION_PRIMARY),
+				address, -1);
+
+	g_free (address);
+}
+
 static GtkActionEntry links_action_entries[] =
 {
+	{ "CopyLinkAddress", 
+	  GTK_STOCK_COPY,
+	  N_("_Copy Link Address"),
+	  NULL,
+	  NULL,
+	  G_CALLBACK (links_copy_link_address_cb) },
 };
 
 static void
 links_info_page_construct (InfoPage *ipage)
 {
 	TreeviewInfoPage *tpage = (TreeviewInfoPage *) ipage;
-	LinksInfoPage *page = (LinksInfoPage *) ipage;
 	PageInfoDialog *dialog = ipage->dialog;
 	GtkTreeView *treeview;
 	GtkListStore *liststore;
@@ -1209,14 +1245,13 @@ links_info_page_construct (InfoPage *ipage)
 	tpage->selection = selection;
 	tpage->treeview = treeview;
 
-//	treeview_info_page_construct (ipage);
+	treeview_info_page_construct (ipage);
 }
 
 static void
 links_info_page_fill (InfoPage *ipage)
 {
 	TreeviewInfoPage *tpage = (TreeviewInfoPage *) ipage;
-	LinksInfoPage *page = (LinksInfoPage *) ipage;
 	PageInfoDialog *dialog = ipage->dialog;
 	GtkListStore *store = tpage->store;
 	GtkTreeIter iter;
@@ -1282,7 +1317,6 @@ static void
 forms_info_page_construct (InfoPage *ipage)
 {
 	TreeviewInfoPage *tpage = (TreeviewInfoPage *) ipage;
-	FormsInfoPage *page = (FormsInfoPage *) ipage;
 	PageInfoDialog *dialog = ipage->dialog;
 
 	GtkTreeView *treeview;
@@ -1353,7 +1387,6 @@ static void
 forms_info_page_fill (InfoPage *ipage)
 {
 	TreeviewInfoPage *tpage = (TreeviewInfoPage *) ipage;
-	ImagesInfoPage *page = (ImagesInfoPage *) ipage;
 	PageInfoDialog *dialog = ipage->dialog;
 	GtkListStore *store = tpage->store;
 	GtkTreeIter iter;
@@ -1400,8 +1433,6 @@ forms_info_page_new (PageInfoDialog *dialog)
 static void
 page_info_dialog_init (PageInfoDialog *dialog)
 {
-	InfoPage *page;
-
 	dialog->priv = PAGE_INFO_DIALOG_GET_PRIVATE (dialog);
 
 	dialog->priv->pages[GENERAL_PAGE] = general_info_page_new (dialog);
@@ -1422,7 +1453,6 @@ page_info_dialog_constructor (GType type,
 	GObject *object;
 	PageInfoDialog *dialog;
 	EphyDialog *edialog;
-	GtkWidget *notebook;
 	GtkAction *action;
 	InfoPage *page;
 	GError *error = NULL;
